<?php
namespace Modules\Parametro\Controllers; 

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;



class Gop21000PercentualPorItemOrcamentoController extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $crudService;
    protected $connection;
    protected $newCode;
    protected $environment;
    protected $dataSourceName = "percitemdetalgop";
    
    
    public function __construct($crudService, ParameterBag $parameterBag, $connection, $newCode, $environment) {
        $this->connection    		= $connection;
        $this->newCode = $newCode;
        $this->environment = $environment;
        parent::__construct($crudService, $parameterBag);
    }

    public function verificaInitUnidade(DTO\Request\Filter $request, DTO\Response $response ){
        
        $filters = $request->getFilterCriteria()->getConditions();
        
        if($filters != null){
            try{
                $newSeq = $this->newCode->getCodeByTableName("PERCITFILGOP", $this->environment->getNrOrg(),11);
                $stmt = $this->connection->prepare("INSERT INTO PERCITFILGOP 
                (NRPERCITFILGOP,  CDFILIAL, NRSEQITEMORCA, DSITEMORCAMENTO, NRORG)
                        SELECT (:P_CODIGO)+ROWNUM, :P_CDFILIAL, P.NRSEQITEMORCA, P.DSITEMORCAMENTO, :P_NRORG  
                        FROM PERCITEMGOP P WHERE P.NRORG = :P_NRORG");
    
                $stmt->execute(
                    array(
                        'P_CODIGO' => $newSeq,
                        'P_CDFILIAL' => $filters[0]['value'], 
                        'P_NRORG' => $this->environment->getNrOrg()
                    )
                );
            }catch(\Exception $ex){
                $response->setError(new Error("Nao foi possivel processar os dados enviados   --- " . $ex->getMessage(), 500));
            }
            
  
        }
    }
    
    public function saveItemOrcamento(DTO\Request $request,  DTO\Response $response) {
		$rows = $request->getDataSet()->getRows();
		try{
	        if(empty($rows))
	            throw new \Exception("Nenhum registro encontrado. Tente novamente!");
	        
	        foreach($rows as $row){
	        	if($row["__is_new"]){
	        	    $this->validateDuplicatedRecords($row, $this->dataSourceName);
	        	    $newCod = $this->newCode->getCodeByTableName("PERCITEMDETALGOP", $this->environment->getNrOrg());
                    $row["NRPERCITEMDETALGOP"] = $newCod;
	        	}
	        }
	        $dataSet = new DataSet($this->dataSourceName, $rows);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
	        $rowsToSave = $this->crudService->getRowsToSave($request, $this->dataSourceName);
	        $dataSet = array ("NRPERCITEMDETALGOP" => $row["NRPERCITEMDETALGOP"]);
	        $this->crudService->save($this->dataSourceName, $rowsToSave);
	        
	        //retorna para o frontend a chave primária (NRPERCITEMDETALGOP) da row salva. 
	        $response->addDataSet(new DataSet("data", $dataSet));
	        
		}catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
	}
    
    public function updateItemOrcamento(DTO\Request $request,  DTO\Response $response) {
        $dados = $request->getDataSet();
        if(!empty($dados)){
            $rows = $dados->getRows();
            if(!empty($rows)){
                try{
                    $dataSet = new DataSet('percitemdetalgop', $rows);
                    $request = new DTO\Request\DataSet($dataSet, "", "", "");
                    $rowsToSave = $this->crudService->getRowsToSave($request, 'percitemdetalgop');
    	            $this->crudService->save('percitemdetalgop', $rowsToSave);
                }catch(\Exception $e){
                    $response->setError(new DTO\Response\Error($e->getMessage(), 1));
                }
            } 
        }
    }
	
	public function saveItemOrcamentoUnidade(DTO\Request $request,  DTO\Response $response) {
		    
		$dataSourceNameUnidade = "percitdetalfilgop";
		$rows = $request->getDataSet()->getRows();
		try{
	        if(empty($rows))
	        throw new \Exception("Nenhum registro encontrado. Tente novamente!");
	        
	        foreach($rows as $row){
	        	if($row["__is_new"]){
	        	    $this->validateDuplicatedRecords($row, $dataSourceNameUnidade);
	        	    $newCod = $this->newCode->getCodeByTableName("PERCITDETALFILGOP", $this->environment->getNrOrg());
                    $row["NRPERCITDETALFILGOP"] = $newCod;
	        	}
	        }
	        $dataSet = new DataSet($dataSourceNameUnidade, $rows);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
            
	        $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceNameUnidade);
	        $dataSet = array ("NRPERCITDETALFILGOP" => $row["NRPERCITDETALFILGOP"]);

	        $this->crudService->save($dataSourceNameUnidade, $rowsToSave);

	        //retorna para o frontend a chave primária (NRPERCITDETALFILGOP) da row salva. 
	        $response->addDataSet(new DataSet("data", $dataSet));
	        
		}catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
	}
    
    public function updateItemOrcamentoUnidade(DTO\Request $request,  DTO\Response $response) {
        $dados = $request->getDataSet();
        if(!empty($dados)){
            $rows = $dados->getRows();
            if(!empty($rows)){
                try{
                    $dataSet = new DataSet('percitdetalfilgop', $rows);
                    $request = new DTO\Request\DataSet($dataSet, "", "", "");
                    $rowsToSave = $this->crudService->getRowsToSave($request, 'percitdetalfilgop');
    	            $this->crudService->save('percitdetalfilgop', $rowsToSave);
                }catch(\Exception $e){
                    $response->setError(new DTO\Response\Error($e->getMessage(), 1));
                }
            } 
        }
    }
	
	public function saveItemMoProdCont(DTO\Request $request,  DTO\Response $response) {
		
		$dataSourceNameGeral = "percdetalprodgop";
		$rows = $request->getDataSet()->getRows();
		try{
	        if(empty($rows))
	            throw new \Exception("Nenhum registro encontrado. Tente novamente!");
	        foreach($rows as $row){
	        	if($row["__is_new"]){
	        	    $newCod = $this->newCode->getCodeByTableName("PERCDETALPRODGOP", $this->environment->getNrOrg());
                    $row["NRPERCDETALPRODGOP"] = $newCod;
	        	}
	        }
	        $dataSet = new DataSet($dataSourceNameGeral, $rows);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
	        $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceNameGeral);
	        $this->crudService->save($dataSourceNameGeral, $rowsToSave);

		}catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
	}
	
	public function updateItemMoProdCont(DTO\Request $request,  DTO\Response $response) {
        $dados = $request->getDataSet();
        if(!empty($dados)){
            $rows = $dados->getRows();
            if(!empty($rows)){
                try{
                    $dataSet = new DataSet('percdetalprodgop', $rows);
                    $request = new DTO\Request\DataSet($dataSet, "", "", "");
                    $rowsToSave = $this->crudService->getRowsToSave($request, 'percdetalprodgop');
    	            $this->crudService->save('percdetalprodgop', $rowsToSave);
                }catch(\Exception $e){
                    $response->setError(new DTO\Response\Error($e->getMessage(), 1));
                }
            } 
        }
    }
    
	public function saveItemMoProdContUnidade(DTO\Request $request,  DTO\Response $response) {
		
		$dataSourceNameUnidade = "percdetprodfilgop";
		$rows = $request->getDataSet()->getRows();
		try{
	        if(empty($rows))
	        throw new \Exception("Nenhum registro encontrado. Tente novamente!");
	        
	        foreach($rows as $row){
	        	    $newCod = $this->newCode->getCodeByTableName("PERCDETPRODFILGOP", $this->environment->getNrOrg());
                    $row["NRPERCDETPRODFILGOP"] = $newCod;
	        }
	        $dataSet = new DataSet($dataSourceNameUnidade, $rows);
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
	        $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceNameUnidade);
	        $this->crudService->save($dataSourceNameUnidade, $rowsToSave);

		}catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
	}
    
    public function updateItemMoProdContUnidade(DTO\Request $request,  DTO\Response $response) {
        $dados = $request->getDataSet();
        if(!empty($dados)){
            $rows = $dados->getRows();
            if(!empty($rows)){
                try{
                    $dataSet = new DataSet('percdetprodfilgop', $rows);
                    $request = new DTO\Request\DataSet($dataSet, "", "", "");
                    $rowsToSave = $this->crudService->getRowsToSave($request, 'percdetprodfilgop');
    	            $this->crudService->save('percdetprodfilgop', $rowsToSave);
                }catch(\Exception $e){
                    $response->setError(new DTO\Response\Error($e->getMessage(), 1));
                }
            } 
        }
    }
    
    public function validateDuplicatedRecords($row, $dataSourceName) {
        //Emanuel: Observação 
        $conditions = array();
        
        $arrayNoFilter = array('__createdLocal' => null, '__is_new' => null, 
        '__index' => null, 'NRORG' => null, 'NMIMPOSTO' => null, 'changed' => null, 'NRPERCITDETALFILGOP'=> null, 'NRPERCITEMDETALGOP' => null, 'NMPRODUTO' => null, 
        'CDARVPROD' => null, 'DSORCAMENTOMO' => null, 'NMDESPPREV' => null, 'VRPERCENTUAL' => null,'NMINVEST'=> null,'NMTIPOOPER'=> null,'DSDESPADMFAT'=> null, '$error'=> null);
        foreach($row as $key => $value){
            if(!array_key_exists($key, $arrayNoFilter)){
                
                if(!empty($value)){
                    array_push($conditions, array(
                        "columnName" => $key,
                        "operator"   => '=',
                        "value"      => $value
                    ));
                }
            }
        }
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);

        if (!empty($dataSet->getRows())) {
            throw new \Exception("Já existe um registro para este item!", 1);
        }
    }
    
    public function cadAutoPercentUnidade(DTO\Request $request, DTO\Response $response ){
        $dataSourceNameUnidade = "percitdetalfilgop";
        $filters = $request->getFilterCriteria()->getConditions();
        
        if($filters != null){
            $cdFilialOrigem = $filters[0]['value'];
            
            $litem = '{
                "imposto": 1,
                "consumo": 2,
                "maoobra": 3,
                "despmatriz": 5,
                "despdiversas": 6,
                "lancentrada": 7,
                "imprecuperar": 8,
                "impsoblucro": 9,
                "investimento": 10,
                "depreciacao": 11
            }';
            $itens = json_decode($litem);
            
            foreach ($filters[1]['value'] as $value) {
                try{
                    $stmt = $this->connection->prepare("DELETE FROM PERCITFILGOP WHERE CDFILIAL = :P_CDFILIAL AND NRORG = :P_NRORG");
        
                    $stmt->execute(
                        array(
                            'P_CDFILIAL' => $value,
                            'P_NRORG' => $this->environment->getNrOrg()
                        )
                    );
                    
                    $count = $this->connection->prepare("SELECT COUNT(1) QTDE
                                                           FROM PERCITFILGOP
                                                          WHERE CDFILIAL = :P_CDFILIAL_ORIG
                                                            AND NRORG = :P_NRORG");
                    $count->execute(
                        array(
                            'P_CDFILIAL_ORIG' => $cdFilialOrigem,
                            'P_NRORG' => $this->environment->getNrOrg()
                        )
                    );
                    $countRows = $count->fetchAll();
                    if ($countRows[0]["QTDE"] !== 0){ 
                        $newSeq = $this->newCode->getCodeByTableName("PERCITFILGOP", $this->environment->getNrorg(),$countRows[0]["QTDE"]+1);
                        $stmt = $this->connection->prepare("INSERT INTO PERCITFILGOP (NRPERCITFILGOP,  CDFILIAL, NRSEQITEMORCA, 
                                                                                      DSITEMORCAMENTO, VRPERCITEMGOP, VRPERCLIMDIAGOP, NRORG, CDOPERINCLUSAO)
                                    SELECT (:P_CODIGO)+ROWNUM, :P_CDFILIAL CDFILIAL, 
                                           NRSEQITEMORCA, DSITEMORCAMENTO, VRPERCITEMGOP, VRPERCLIMDIAGOP, NRORG, :P_CDOPERINCLUSAO
                                      FROM PERCITFILGOP
                                     WHERE CDFILIAL = :P_CDFILIAL_ORIG
                                       AND NRORG = :P_NRORG");
                        $stmt->execute(
                            array(
                                'P_CODIGO' => $newSeq,
                                'P_CDFILIAL' => $value, 
                                'P_CDFILIAL_ORIG' => $cdFilialOrigem,
                                'P_NRORG' => $this->environment->getNrOrg(),
                                'P_CDOPERINCLUSAO' => $this->environment-> getCdOperador()
                            )
                        );
                    }
                    
                    $count = $this->connection->prepare("SELECT COUNT(1) QTDE
                                  FROM PERCITFILGOP P INNER JOIN PERCITFILGOP PI ON PI.NRORG = P.NRORG
                                                      INNER JOIN PERCITDETALFILGOP I ON PI.NRPERCITFILGOP = I.NRPERCITFILGOP
                                                                                    AND PI.NRORG = I.NRORG
                                 WHERE P.CDFILIAL = :P_CDFILIAL
                                   AND P.NRSEQITEMORCA = PI.NRSEQITEMORCA
                                   AND PI.CDFILIAL = :P_CDFILIAL_ORIG
                                   AND PI.NRSEQITEMORCA = :P_ITEM
                                   AND PI.NRORG = :P_NRORG");
    
                    foreach($itens as $key=>$id){
                        $count->execute(
                            array(
                                'P_CDFILIAL' => $value, 
                                'P_CDFILIAL_ORIG' => $cdFilialOrigem,
                                'P_NRORG' => $this->environment->getNrOrg(),
                                'P_ITEM' => $id
                            )
                        );
                        $countRows = $count->fetchAll();
                        
                        if ($countRows[0]["QTDE"] !== 0){ 
                            $newSeq = $this->newCode->getCodeByTableName("PERCITDETALFILGOP", $this->environment->getNrorg(),$countRows[0]["QTDE"]+1);
                            $stmt = $this->connection->prepare("INSERT INTO PERCITDETALFILGOP 
                                (NRPERCITFILGOP, NRPERCITDETALFILGOP, CDFILIAL, CDPRODUTO, CDIMPOSTO, CDTIPOOPER, IDENTRSAIDOP, 
                                 CDINVEST, CDDESPADMFAT, CDDESPPREV, VRPERCENTUAL, VRPERCLIMDIAGOP, NRORG, IDDESPPREV, CDOPERINCLUSAO, CDFATUDIVER)
                                SELECT P.NRPERCITFILGOP, (:P_CODIGO)+ROWNUM, P.CDFILIAL, 
                                       I.CDPRODUTO, I.CDIMPOSTO, I.CDTIPOOPER, I.IDENTRSAIDOP, I.CDINVEST, I.CDDESPADMFAT,
                                       I.CDDESPPREV, I.VRPERCENTUAL, I.VRPERCLIMDIAGOP, I.NRORG, I.IDDESPPREV,:P_CDOPERINCLUSAO, I.CDFATUDIVER
                                  FROM PERCITFILGOP P INNER JOIN PERCITFILGOP PI ON PI.NRORG = P.NRORG
                                                      INNER JOIN PERCITDETALFILGOP I ON PI.NRPERCITFILGOP = I.NRPERCITFILGOP
                                                                                    AND PI.NRORG = I.NRORG
                                 WHERE P.CDFILIAL = :P_CDFILIAL
                                   AND P.NRSEQITEMORCA = PI.NRSEQITEMORCA
                                   AND PI.CDFILIAL = :P_CDFILIAL_ORIG
                                   AND PI.NRSEQITEMORCA = :P_ITEM
                                   AND PI.NRORG = :P_NRORG");
                                       
                            $stmt->execute(
                                array(
                                    'P_CODIGO' => $newSeq,
                                    'P_CDFILIAL' => $value, 
                                    'P_CDFILIAL_ORIG' => $cdFilialOrigem,
                                    'P_NRORG' => $this->environment->getNrOrg(),
                                    'P_ITEM' => $id,
                                    'P_CDOPERINCLUSAO' => $this->environment->getCdOperador()
                                )
                            );
                        }
                    };
                    
                    $count = $this->connection->prepare("SELECT COUNT(1) QTDE
                                  FROM PERCITDETALFILGOP D INNER JOIN PERCITFILGOP DX ON D.NRPERCITFILGOP = DX.NRPERCITFILGOP
                                                                                     AND D.NRORG = DX.NRORG
                                                           INNER JOIN PERCDETPRODFILGOP DI ON DI.NRORG = DX.NRORG  
                                                           INNER JOIN PERCITDETALFILGOP PI ON PI.NRPERCITDETALFILGOP = DI.NRPERCITDETALFILGOP
                                                                                          AND PI.NRORG = DI.NRORG                           
                                                           INNER JOIN PERCITFILGOP PP ON PI.NRPERCITFILGOP = PP.NRPERCITFILGOP
                                                                                     AND PI.NRORG = PP.NRORG                           
                                 WHERE DX.CDFILIAL = :P_CDFILIAL
                                   AND DX.NRSEQITEMORCA = PP.NRSEQITEMORCA
                                   AND PP.CDFILIAL = :P_CDFILIAL_ORIG
                                   AND PP.NRSEQITEMORCA = :P_ITEM
                                   AND PP.NRORG = :P_NRORG");
                    foreach($itens as $key=>$id){
                        $count->execute(
                            array(
                                'P_CDFILIAL' => $value, 
                                'P_CDFILIAL_ORIG' => $cdFilialOrigem,
                                'P_NRORG' => $this->environment->getNrOrg(),
                                'P_ITEM' => $id
                            )
                        );
                        $countRows = $count->fetchAll();
                        
                        if ($countRows[0]["QTDE"] !== 0){ 
                            $newSeq = $this->newCode->getCodeByTableName("PERCDETPRODFILGOP", $this->environment->getNrorg(),$countRows[0]["QTDE"]+1);
                        
                            $stmt = $this->connection->prepare("INSERT INTO PERCDETPRODFILGOP 
                                        (NRPERCITDETALFILGOP, NRPERCDETPRODFILGOP, CDFILIAL, CDPRODUTO, 
                                         CDDESPADMFAT, CDTIPOOPER, IDENTRSAIDOP, VRPERCENTUAL, 
                                         VRPERCLIMDIAGOP, NRORG, CDOPERINCLUSAO)
                                        SELECT D.NRPERCITDETALFILGOP, (:P_CODIGO)+ROWNUM, DX.CDFILIAL, DI.CDPRODUTO, 
                                               DI.CDDESPADMFAT, DI.CDTIPOOPER, DI.IDENTRSAIDOP, DI.VRPERCENTUAL, DI.VRPERCLIMDIAGOP, DI.NRORG, :P_CDOPERINCLUSAO
                                          FROM PERCITDETALFILGOP D INNER JOIN PERCITFILGOP DX ON D.NRPERCITFILGOP = DX.NRPERCITFILGOP
                                                                                             AND D.NRORG = DX.NRORG
                                                                   INNER JOIN PERCDETPRODFILGOP DI ON DI.NRORG = DX.NRORG  
                                                                   INNER JOIN PERCITDETALFILGOP PI ON PI.NRPERCITDETALFILGOP = DI.NRPERCITDETALFILGOP
                                                                                                  AND PI.NRORG = DI.NRORG                           
                                                                   INNER JOIN PERCITFILGOP PP ON PI.NRPERCITFILGOP = PP.NRPERCITFILGOP
                                                                                             AND PI.NRORG = PP.NRORG                           
                                         WHERE DX.CDFILIAL = :P_CDFILIAL
                                           AND DX.NRSEQITEMORCA = PP.NRSEQITEMORCA
                                           AND PP.CDFILIAL = :P_CDFILIAL_ORIG
                                           AND PP.NRSEQITEMORCA = :P_ITEM
                                           AND PP.NRORG = :P_NRORG");

                            $stmt->execute(
                                array(
                                    'P_CODIGO' => $newSeq,
                                    'P_CDFILIAL' => $value, 
                                    'P_CDFILIAL_ORIG' => $cdFilialOrigem,
                                    'P_NRORG' => $this->environment->getNrOrg(),
                                    'P_ITEM' => $id,
                                    'P_CDOPERINCLUSAO' => $this->environment->getCdOperador()
                                )
                            );
                        }
                    };
                }catch(\Exception $ex){
                    $response->setError(new Error("Nao foi possivel processar os dados enviados   --- " . $ex->getMessage(), 500));
                }
            }
        }
    }
    
    public function validateUnity(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        try {
            $params = array('P_CDFILIAL' => $row['CDFILIAL']);
            $query = "SELECT 
                            P.IDCONSFATUDIV,
                            P.CDFILIAL
                        FROM PARFILIALROP P
                       WHERE P.CDFILIAL = TIPOPARAM_DRO(:P_CDFILIAL)";
       
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $response->addDataSet(new DataSet("data", $stmt->fetchAll()));
        } catch (Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
        
    }
    
    public function saveFat(DTO\Request $request, DTO\Response $response) {
        $rows = $request->getDataSet()->getRows();
        $cdfilial = $request->getParameter("unidade");
        try{
            $validateParentTable = $this->validateParentTable($cdfilial);
            $codParent = "";
            if(\Zeedhi\Framework\Util\Functions::arrayKeyExists('NRPERCITFILGOP', $validateParentTable)){
                $codParent = $validateParentTable[0]["NRPERCITFILGOP"];
            } else{
                $codParent = $this->insertFatUnity($cdfilial);
            }
            
            foreach ($rows as $row){
                $this->insertUnityDetail($cdfilial, $codParent, $row["CDFATUDIVER"], $row["CDPRODUTO"]);
            }
        } catch (Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        } 
    }
    
    public function insertFatUnity($cdfilial){
        $newCod = $this->newCode->getCodeByTableName("PERCITFILGOP", $this->environment->getNrOrg());
        $params = [
            'P_CDFILIAL' => $cdfilial,
            'P_NRPERCITFILGOP' => $newCod,
            'P_NRORG' => $this->environment->getNrOrg(),
        ];
        $query = "INSERT INTO PERCITFILGOP (NRPERCITFILGOP, CDFILIAL, NRSEQITEMORCA, DSITEMORCAMENTO, NRORG)
                  VALUES (:P_NRPERCITFILGOP, :P_CDFILIAL, 0, 'Faturamento', :P_NRORG)";
        
        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        return $newCod;
    }
    
    public function insertUnityDetail($cdfilial, $codParent, $cdfatudiver, $cdproduto){
        $newCod = $this->newCode->getCodeByTableName("PERCITDETALFILGOP", $this->environment->getNrOrg());
        $params = [
            'P_CDFILIAL' => $cdfilial,
            'P_NRPERCITFILGOP' => $codParent,
            'P_NRPERCITDETALFILGOP' => $newCod,
            'P_CDFATUDIVER' => $cdfatudiver,
            'P_CDPRODUTO' => $cdproduto,
            'P_NRORG' => $this->environment->getNrOrg(),
        ];
        $query = "INSERT INTO PERCITDETALFILGOP (NRPERCITFILGOP, NRPERCITDETALFILGOP, CDFILIAL, VRPERCENTUAL, CDFATUDIVER, CDPRODUTO, NRORG)
                  SELECT   :P_NRPERCITFILGOP, 
                           :P_NRPERCITDETALFILGOP, 
                           :P_CDFILIAL, 
                           0, 
                           :P_CDFATUDIVER,
                           :P_CDPRODUTO,
                           :P_NRORG
                    FROM   DUAL
                   WHERE NOT EXISTS (
                        SELECT 1 
                          FROM PERCITDETALFILGOP
                         WHERE ((CDFATUDIVER = :P_CDFATUDIVER AND :P_CDFATUDIVER IS NOT NULL)
                            OR (CDPRODUTO = :P_CDPRODUTO AND :P_CDPRODUTO IS NOT NULL))
                           AND NRPERCITFILGOP = :P_NRPERCITFILGOP)";
        
        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        return $newCod;
    }
    
    public function validateParentTable($cdfilial){
        $params = ['P_CDFILIAL' => $cdfilial];
        $query = "SELECT NRPERCITFILGOP 
                    FROM PERCITFILGOP 
                   WHERE NRSEQITEMORCA = 0
                     AND CDFILIAL = :P_CDFILIAL";
        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        $dataResponse = $stmt->fetchAll();
        return $dataResponse;
    }
    
    public function validBillingRegistration($params){
           $query = "SELECT   
                            P.NRPERCITFILGOP,
                            P.NRPERCITDETALFILGOP,
                            P.CDFILIAL,
                            P.CDFATUDIVER,
                            P.NRORG
                        FROM PERCITDETALFILGOP P 
                               INNER JOIN  FATUDIVER F ON P.CDFATUDIVER = F.CDFATUDIVER
                       WHERE P.CDFILIAL = :P_CDFILIAL
                         AND P.CDFATUDIVER = :P_CDFATUDIVER
                         AND P.NRORG = :P_NRORG";
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            return $result;
    }
    
    public function delFat(DTO\Request $request, DTO\Response $response) {
        $rows = $request->getDataSet()->getRows();
        foreach ($rows as $row){
            $params = [
                'P_NRPERCITDETALFILGOP' => $row["NRPERCITDETALFILGOP"],
            ];
            $query = "DELETE
                        FROM PERCITDETALFILGOP
                       WHERE NRPERCITDETALFILGOP = :P_NRPERCITDETALFILGOP";
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        }
    }
    
}